@@ -92,8 +92,8 @@ class GeoElevationData:
         data_file_name = file_name
         zip_data_file_name = '{0}.zip'.format(file_name)
 
-        if mod_path.exists(data_file_name):
-            return mod_path.file_handler.read(data_file_name)
+        if self.file_handler.exists(data_file_name):
+            return self.file_handler.read(data_file_name)
         elif self.file_handler.exists(zip_data_file_name):
             data = self.file_handler.read(zip_data_file_name)
             return mod_utils.unzip(data)
@@ -227,6 +227,10 @@ class GeoElevationFile:
 
         self.square_side = int(square_side)
 
+    def get_row_and_column(self, latitude, longitude):
+        return mod_math.floor((self.latitude + 1 - latitude) * float(self.square_side - 1)), \
+               mod_math.floor((longitude - self.longitude) * float(self.square_side - 1))
+
     def get_elevation(self, latitude, longitude, approximate=None):
         """
         If approximate is True then only the points from SRTM grid will be 
@@ -239,8 +243,7 @@ class GeoElevationFile:
 
         points = self.square_side ** 2
 
-        row = mod_math.floor((self.latitude + 1 - latitude) * float(self.square_side - 1))
-        column = mod_math.floor((longitude - self.longitude) * float(self.square_side - 1))
+        row, column = self.get_row_and_column(latitude, longitude)
 
         if approximate:
             return self.approximation(latitude, longitude)
